#[non_exhaustive]pub struct ImageSigningStatus {
pub signing_profile_arn: Option<String>,
pub failure_code: Option<String>,
pub failure_reason: Option<String>,
pub status: Option<SigningStatus>,
}Expand description
The signing status for an image. Each status corresponds to a signing profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signing_profile_arn: Option<String>The ARN of the Amazon Web Services Signer signing profile used to sign the image.
failure_code: Option<String>The failure code, which is only present if status is FAILED.
failure_reason: Option<String>A description of why signing the image failed. This field is only present if status is FAILED.
status: Option<SigningStatus>The image's signing status. Possible values are:
-
IN_PROGRESS- Signing is currently in progress. -
COMPLETE- The signature was successfully generated. -
FAILED- Signing failed. SeefailureCodeandfailureReasonfor details.
Implementations
Sourceimpl ImageSigningStatus
impl ImageSigningStatus
Sourcepub fn signing_profile_arn(&self) -> Option<&str>
pub fn signing_profile_arn(&self) -> Option<&str>
The ARN of the Amazon Web Services Signer signing profile used to sign the image.
Sourcepub fn failure_code(&self) -> Option<&str>
pub fn failure_code(&self) -> Option<&str>
The failure code, which is only present if status is FAILED.
Sourcepub fn failure_reason(&self) -> Option<&str>
pub fn failure_reason(&self) -> Option<&str>
A description of why signing the image failed. This field is only present if status is FAILED.
Sourcepub fn status(&self) -> Option<&SigningStatus>
pub fn status(&self) -> Option<&SigningStatus>
The image's signing status. Possible values are:
-
IN_PROGRESS- Signing is currently in progress. -
COMPLETE- The signature was successfully generated. -
FAILED- Signing failed. SeefailureCodeandfailureReasonfor details.
Sourceimpl ImageSigningStatus
impl ImageSigningStatus
Sourcepub fn builder() -> ImageSigningStatusBuilder
pub fn builder() -> ImageSigningStatusBuilder
Creates a new builder-style object to manufacture ImageSigningStatus.