#[non_exhaustive]pub struct SigningRule {
pub signing_profile_arn: String,
pub repository_filters: Option<Vec<SigningRepositoryFilter>>,
}Expand description
A signing rule that specifies a signing profile and optional repository filters. When an image is pushed to a matching repository, a signing job is created using the specified profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signing_profile_arn: StringThe ARN of the Amazon Web Services Signer signing profile to use for signing images that match this rule. For more information about signing profiles, see Signing profiles in the Amazon Web Services Signer Developer Guide.
repository_filters: Option<Vec<SigningRepositoryFilter>>A list of repository filters that determine which repositories have their images signed on push. If no filters are specified, all images pushed to the registry are signed using the rule's signing profile. Maximum of 100 filters per rule.
Implementations
Sourceimpl SigningRule
impl SigningRule
Sourcepub fn signing_profile_arn(&self) -> &str
pub fn signing_profile_arn(&self) -> &str
The ARN of the Amazon Web Services Signer signing profile to use for signing images that match this rule. For more information about signing profiles, see Signing profiles in the Amazon Web Services Signer Developer Guide.
Sourcepub fn repository_filters(&self) -> &[SigningRepositoryFilter]
pub fn repository_filters(&self) -> &[SigningRepositoryFilter]
A list of repository filters that determine which repositories have their images signed on push. If no filters are specified, all images pushed to the registry are signed using the rule's signing profile. Maximum of 100 filters per rule.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .repository_filters.is_none().
Sourceimpl SigningRule
impl SigningRule
Sourcepub fn builder() -> SigningRuleBuilder
pub fn builder() -> SigningRuleBuilder
Creates a new builder-style object to manufacture SigningRule.